@@ -2,7 +2,7 @@ import logging
 from os import getcwd
 from os.path import dirname
 
-__version__ = '0.3.13'
+__version__ = '0.3.15'
 basedir = dirname(__file__)
 
 # create logger
@@ -43,13 +43,3 @@ def initial_log_messages(name: str):
     logger.debug('Directory: {}'.format(getcwd()))
     logger.debug('Date:      {}'.format(datetime.now()))
     logger.debug('')
-
-
-from sonusai.version import version  # noqa: E402
-from sonusai.create_onnx_from_keras import create_onnx_from_keras  # noqa: E402
-from sonusai.evaluate import evaluate  # noqa: E402
-from sonusai.genmix import genmix  # noqa: E402
-from sonusai.genft import genft  # noqa: E402
-from sonusai.genmixdb import genmixdb  # noqa: E402
-from sonusai.gentcst import gentcst  # noqa: E402
-from sonusai.data_generator import DataGenerator  # noqa: E402
