@@ -27,7 +27,7 @@ def create_onnx_from_keras(model,
     # convert to onnx model
     # spec = (tf.TensorSpec((None, 224, 224, 3), tf.float32, name="input"),)
     # onnx_model, _ = tf2onnx.convert.from_keras(model)
-    onnx_model = keras2onnx.convert_keras(model, name, debug_mode=True)
+    onnx_model = keras2onnx.convert_keras(model, name, debug_mode=True, target_opset=13)
 
     # Replace stateful GRUs with custom layers
     stateful_gru_names = []
