@@ -1,18 +1,26 @@
 """evaluate
 
-usage: evaluate [-hv] (-f FEATURE) [-n PRED] [-b BTHR] [-p PLOTNUM]
+usage: evaluate [-hv] (-f FEATURE) [-n PREDICT] [-b BTHR] [-p PLOTNUM]
 
 options:
    -h, --help
    -v, --verbose                    Be verbose.
    -f FEATURE, --feature FEATURE    Feature .h5 data file.
-   -n PRED, --pred PRED             Optional predict .h5 data file.
+   -n PREDICT, --predict PREDICT    Optional predict .h5 data file.
    -b BTHR, --bthr BTHR             Optional binary detection threshold, 0 = argmax(). [default: 0].
    -p PLOTNUM, --plotnum PLOTNUM    Optional plot mixture results (-1 is plot all, 0 is plot none) [default: 0].
 
 The evaluate command measures performance of neural-network models from frame-by-frame truth and prediction data.
 It supports data mixtures of target and noise files at various SNR levels as created by sonusai genft function.
 
+Inputs:
+    FEATURE     A SonusAI feature HDF5 file. Contains:
+                    dataset:    feature
+                    dataset:    truth_f
+                    dataset:    segsnr
+                    attribute:  mixdb
+    PREDICT     A SonusAI predict HDF5 file. Contains:
+                    dataset:    predict (either [frames, num_classes] or [frames, timesteps, num_classes])
 """
 from datetime import datetime
 from os import mkdir
@@ -26,11 +34,11 @@ from docopt import docopt
 from matplotlib import pyplot as plt
 from matplotlib.backends.backend_pdf import PdfPages
 
+import sonusai
 from sonusai import create_file_handler
 from sonusai import initial_log_messages
 from sonusai import logger
 from sonusai import update_console_handler
-from sonusai import version
 from sonusai.metrics import averages
 from sonusai.metrics import calculate_metrics
 from sonusai.metrics import format_confusion_matrix
@@ -675,12 +683,12 @@ def save_eval_report(output_dir, noise_files, target_files, snrs, fnameidx, dfna
 
 def main():
     try:
-        args = docopt(trim_docstring(__doc__), version=version(), options_first=True)
+        args = docopt(trim_docstring(__doc__), version=sonusai.__version__, options_first=True)
 
         feature_name = args['--feature']
 
-        if args['--pred']:
-            predict_name = args['--pred']
+        if args['--predict']:
+            predict_name = args['--predict']
         else:
             predict_name = ''
 
