@@ -17,14 +17,17 @@ Inputs:
                 If no file is provided, then all mixtures in the database will be generated.
 
 Outputs:
-    OUTPUT.h5   A SonusAI feature HDF5 file (containing 'feature' and 'truth_f' datasets).
+    OUTPUT.h5   A SonusAI feature HDF5 file. Contains:
+                    dataset:    feature
+                    dataset:    truth_f
+                    dataset:    segsnr
+                    attribute:  mixdb
     genft.log
 
 """
 
 import json
 from copy import deepcopy
-from itertools import zip_longest
 from os.path import exists
 from os.path import splitext
 from typing import List
@@ -50,6 +53,7 @@ from sonusai.mixture import get_mixtures_from_mixid
 from sonusai.mixture import get_total_class_count
 from sonusai.mixture import process_mixture_audio
 from sonusai.mixture import truth_reduction
+from sonusai.utils import grouper
 from sonusai.utils import human_readable_size
 from sonusai.utils import int16_to_float
 from sonusai.utils import seconds_to_hms
@@ -59,8 +63,10 @@ from sonusai.utils import trim_docstring
 def genft(mixdb: dict,
           mixid: Union[str, List[int]],
           start_offset: int = 0,
+          compute_segsnr: bool = False,
           logging: bool = True,
-          show_progress: bool = False) -> (np.ndarray, np.ndarray, dict):
+          show_progress: bool = False,
+          progress: tqdm = None) -> (np.ndarray, np.ndarray, dict):
     mixdb_out = deepcopy(mixdb)
     mixdb_out['mixtures'] = get_mixtures_from_mixid(mixdb_out['mixtures'], mixid)
 
@@ -91,11 +97,17 @@ def genft(mixdb: dict,
     noise_audios = build_noise_audio_db(mixdb_out)
     target_audios = build_target_audio_db(mixdb_out)
 
+    segsnr = np.empty(0)
+    if compute_segsnr:
+        segsnr = np.empty(total_samples, dtype=np.single)
+
     i_sample_offset = 0
     i_frame_offset = 0
     o_frame_offset = 0
     feature_frame = 0
-    for mixture_record in tqdm(mixdb_out['mixtures'], desc='genft', disable=not show_progress):
+    if progress is None:
+        progress = tqdm(total=len(mixdb_out['mixtures']), desc='genft', disable=not show_progress)
+    for mixture_record in mixdb_out['mixtures']:
         noise_audio, target_audio = process_mixture_audio(i_frame_offset=i_frame_offset,
                                                           i_sample_offset=i_sample_offset,
                                                           o_frame_offset=o_frame_offset,
@@ -109,6 +121,12 @@ def genft(mixdb: dict,
         truth = generate_truth(mixdb=mixdb_out, mixture_record=mixture_record, target_audio=target_audio)
 
         for offset in range(0, mixture_record['samples'], mixdb_out['frame_size']):
+            if compute_segsnr:
+                target_energy = fft.energy(int16_to_float(target_audio[offset:offset + mixdb_out['frame_size']]))
+                noise_energy = fft.energy(int16_to_float(noise_audio[offset:offset + mixdb_out['frame_size']]))
+                frame_offset = i_sample_offset + offset
+                segsnr[frame_offset:frame_offset + mixdb_out['frame_size']] = np.single(target_energy / noise_energy)
+
             mixture_fd = fft.execute(int16_to_float(mixture_audio[offset:offset + mixdb_out['frame_size']]))
             fg.execute(mixture_fd,
                        truth_reduction(truth[:, offset:offset + mixdb_out['frame_size']],
@@ -129,6 +147,7 @@ def genft(mixdb: dict,
         i_sample_offset += mixture_record['samples']
         i_frame_offset += mixture_record['samples'] // mixdb_out['frame_size']
         o_frame_offset += mixture_record['samples'] // mixdb_out['feature_step_samples']
+        progress.update()
 
     mixdb_out['class_count'] = get_total_class_count(mixdb_out)
 
@@ -138,19 +157,15 @@ def genft(mixdb: dict,
         logger.info('Duration: {}'.format(seconds_to_hms(seconds=duration)))
         logger.info('feature:  {}'.format(human_readable_size(feature.nbytes, 1)))
         logger.info('truth_f:  {}'.format(human_readable_size(truth_f.nbytes, 1)))
+        if compute_segsnr:
+            logger.info('segsnr:   {}'.format(human_readable_size(segsnr.nbytes, 1)))
 
-    return feature, truth_f, mixdb_out
-
-
-def grouper(iterable, n):
-    args = [iter(iterable)] * n
-    result = zip_longest(*args, fillvalue=None)
-    return [list(filter(None.__ne__, x)) for x in result]
+    return feature, truth_f, segsnr, mixdb_out
 
 
 def main():
     try:
-        args = docopt(trim_docstring(__doc__), version=sonusai.version(), options_first=True)
+        args = docopt(trim_docstring(__doc__), version=sonusai.__version__, options_first=True)
 
         verbose = args['--verbose']
         mixdb_name = args['--mixdb']
@@ -186,21 +201,40 @@ def main():
                     exit()
                 mixid = mixid['mixid']
 
-        mixtures = get_mixtures_from_mixid(mixdb['mixtures'], mixid)
+        mixdb_out = deepcopy(mixdb)
+        mixdb_out['mixtures'] = get_mixtures_from_mixid(mixdb_out['mixtures'], mixid)
 
-        mixid = grouper(mixid, 100)
-        frame_offset = 0
+        if not mixdb_out['mixtures']:
+            logger.error('Error processing mixid: {}; resulted in empty list of mixtures'.format(mixid))
+            exit()
+
+        total_samples = sum([sub['samples'] for sub in mixdb_out['mixtures']])
+
+        chunk_size = 100
+        progress = tqdm(total=len(mixid), desc='genft')
+        mixid = grouper(range(len(mixdb_out['mixtures'])), chunk_size)
+        mixdb_out['class_count'] = [0] * mixdb_out['num_classes']
+
+        i_frame_offset = 0
+        o_frame_offset = 0
+        chunk_offset = 0
         feature_elems = 0
         truth_elems = 0
         with h5py.File(output_name, 'w') as f:
-            for idx, val in enumerate(mixid):
-                logger.info('Processing chunk {} of {}'.format(idx + 1, len(mixid)))
-                feature, truth_f, _ = genft(mixdb=mixdb,
-                                            mixid=val,
-                                            logging=False,
-                                            show_progress=True)
+            for m in mixid:
+                feature, truth_f, segsnr, mixdb_tmp = genft(mixdb=mixdb_out,
+                                                            mixid=m,
+                                                            compute_segsnr=True,
+                                                            logging=False,
+                                                            progress=progress)
+                o_frames = feature.shape[0]
+                if o_frames != truth_f.shape[0]:
+                    logger.error(
+                        'truth_f frames does not match feature frames: {} != {}'.format(o_frames, truth_f.shape[0]))
+                    exit()
 
-                if frame_offset == 0:
+                progress.refresh()
+                if o_frame_offset == 0:
                     feature_dataset = f.create_dataset(name='feature',
                                                        data=feature,
                                                        maxshape=(None, feature.shape[1], feature.shape[2]))
@@ -210,19 +244,37 @@ def main():
                     feature_elems = feature.shape[1] * feature.shape[2]
                     truth_elems = truth_f.shape[1]
                 else:
-                    feature_dataset.resize(frame_offset + feature.shape[0], axis=0)
-                    feature_dataset[frame_offset:] = feature
-                    truth_dataset.resize(frame_offset + feature.shape[0], axis=0)
-                    truth_dataset[frame_offset:] = truth_f
-                frame_offset += feature.shape[0]
+                    feature_dataset.resize(o_frame_offset + o_frames, axis=0)
+                    feature_dataset[o_frame_offset:] = feature
+                    truth_dataset.resize(o_frame_offset + o_frames, axis=0)
+                    truth_dataset[o_frame_offset:] = truth_f
+                o_frame_offset += o_frames
+
+                i_frames = segsnr.shape[0]
+                if i_frame_offset == 0:
+                    segsnr_dataset = f.create_dataset(name='segsnr',
+                                                      data=segsnr,
+                                                      maxshape=(None,))
+                else:
+                    segsnr_dataset.resize(i_frame_offset + i_frames, axis=0)
+                    segsnr_dataset[i_frame_offset:] = segsnr
+                i_frame_offset += i_frames
+
+                for idx, val in enumerate(m):
+                    mixdb_out['mixtures'][val] = mixdb_tmp['mixtures'][idx]
+                for idx in range(mixdb_out['num_classes']):
+                    mixdb_out['class_count'][idx] += mixdb_tmp['class_count'][idx]
+                chunk_offset += chunk_size
+            f.attrs['mixdb'] = json.dumps(mixdb_out)
+        progress.close()
 
         logger.info('Wrote {}'.format(output_name))
-        total_samples = sum([sub['samples'] for sub in mixtures])
         duration = total_samples / sonusai.mixture.sample_rate
         logger.info('')
         logger.info('Duration: {}'.format(seconds_to_hms(seconds=duration)))
-        logger.info('feature:  {}'.format(human_readable_size(frame_offset * feature_elems * 4, 1)))
-        logger.info('truth_f:  {}'.format(human_readable_size(frame_offset * truth_elems * 4, 1)))
+        logger.info('feature:  {}'.format(human_readable_size(o_frame_offset * feature_elems * 4, 1)))
+        logger.info('truth_f:  {}'.format(human_readable_size(o_frame_offset * truth_elems * 4, 1)))
+        logger.info('segsnr:   {}'.format(human_readable_size(i_frame_offset * 4, 1)))
 
     except KeyboardInterrupt:
         logger.info('Canceled due to keyboard interrupt')
