@@ -246,12 +246,11 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
         logger.error('invalid truth_mode: {}'.format(config['truth_mode']))
         exit()
 
-    if config['truth_mode'] == 'mutex':
+    truth_mutex = config['truth_mode'] == 'mutex'
+    if truth_mutex:
         max_class = config['num_classes'] - 1
-        truth_mutex = 1
     else:
         max_class = config['num_classes']
-        truth_mutex = 0
 
     fg = FeatureGenerator(feature_mode=config['feature'],
                           frame_size=config['frame_size'],
@@ -619,7 +618,7 @@ def process_mixture(mixture: dict,
                     raw_target_audio: list,
                     augmented_noise_audio: np.ndarray,
                     feature_step_samples: int,
-                    truth_mutex: int,
+                    truth_mutex: bool,
                     class_weights_threshold: list) -> dict:
     target_index = mixture['target_file_index']
     noise_offset = mixture['noise_offset']
@@ -708,7 +707,7 @@ def process_mixture(mixture: dict,
 
 def main():
     try:
-        args = docopt(trim_docstring(__doc__), version=sonusai.version(), options_first=True)
+        args = docopt(trim_docstring(__doc__), version=sonusai.__version__, options_first=True)
 
         verbose = args['--verbose']
 
