@@ -27,11 +27,11 @@ def calculate_class_weights(truth: np.ndarray, oweight: int = -1, oweight_idx: i
         cnt = np.bincount(tlabels, minlength=num_classes).astype(float)
 
     if oweight > 0:
-        if oweight_idx < 0:
-            oweight_idx = num_classes - 1  # default to last class
         cnt[oweight_idx] = cnt[oweight_idx] / oweight
 
-    cweights = frames / (num_classes * cnt)  # avoid sklearn problem with absent classes
-    cweights[cweights == np.inf] = 0  # just assign non-existent class weight of 0
+    cweights = np.empty((len(cnt)))
+    for n in range(len(cnt)):
+        # avoid sklearn problem with absent classes and assign non-existent class weight of 0
+        cweights[n] = frames / (num_classes * cnt[n]) if cnt[n] else 0
 
     return cweights
