@@ -8,7 +8,7 @@ def get_class_count(truth_index: List[int],
                     class_weights_threshold: List[float]) -> List[int]:
     class_count = [0] * len(truth_index)
     for idx, cl in enumerate(truth_index):
-        truth_sum = int(np.sum(truth[cl - 1, :] >= class_weights_threshold[cl - 1]))
+        truth_sum = int(np.sum(truth[cl - 1,] >= class_weights_threshold[cl - 1]))
         class_count[idx] = truth_sum
 
     return class_count
